@@ -4,8 +4,12 @@ def path_maker(path_list=[],relative_path='.',start_path=None):
     '''
     start_path=None=>os.getcwd()
     '''
-    start_path = os.getcwd() if start_path==None else start_path
-    p = os.path.abspath(os.path.join(start_path,relative_path))
+    if (sep_path := os.environ.get('start_path',''))!='':
+        p = os.path.dirname(__file__).split(sep_path)[0]+sep_path
+        p = p.rstrip(os.sep)
+    else:
+        start_path = os.getcwd() if start_path==None else start_path
+        p = os.path.abspath(os.path.join(start_path,relative_path))
     for i in path_list:
         p += '/'+str(i)
         if not os.path.exists(p):
@@ -22,3 +26,7 @@ def zipfolder(zip_addr:str, target_dir):
             fn = os.path.join(base, file)
             zipobj.write(fn, fn[rootlen:])
     return zip_addr
+
+def unziper(path_to_zip_file,directory_to_extract_to):
+    with zipfile.ZipFile(path_to_zip_file, 'r') as zip_ref:
+        zip_ref.extractall(directory_to_extract_to)
\ No newline at end of file
